/******************************************************************************/
/*                                                                            */
/*  Title       : satglobalsx.h                                               */
/*  Author      : Manfred Bester, DL5KR                                       */
/*  Date        : 03Mar92                                                     */
/*  Last change : 05Oct94                                                     */
/*                                                                            */
/*  Synopsis    : Declarations of external variables and functions for        */
/*                'sattrack'.                                                 */
/*                                                                            */
/*                                                                            */
/*  Copyright (c) 1992, 1993, 1994 Manfred Bester. All Rights Reserved.       */
/*                                                                            */
/*  Permission to use, copy, modify, and distribute this software and its     */
/*  documentation for educational, research and non-profit purposes, without  */
/*  fee, and without a written agreement is hereby granted, provided that the */
/*  above copyright notice and the following three paragraphs appear in all   */
/*  copies.                                                                   */
/*                                                                            */
/*  Permission to incorporate this software into commercial products may be   */
/*  obtained from the author, Dr. Manfred Bester, 1636 M. L. King Jr. Way,    */
/*  Berkeley, CA 94709, USA.                                                  */
/*                                                                            */
/*  IN NO EVENT SHALL THE AUTHOR BE LIABLE TO ANY PARTY FOR DIRECT, INDIRECT, */
/*  SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OF   */
/*  THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF THE AUTHOR HAS BEEN ADVISED  */
/*  OF THE POSSIBILITY OF SUCH DAMAGE.                                        */
/*                                                                            */
/*  THE AUTHOR SPECIFICALLY DISCLAIMS ANY WARRANTIES, INCLUDING, BUT NOT      */
/*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A   */
/*  PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON AN "AS IS"      */
/*  BASIS, AND THE AUTHOR HAS NO OBLIGATIONS TO PROVIDE MAINTENANCE, SUPPORT, */
/*  UPDATES, ENHANCEMENTS, OR MODIFICATIONS.                                  */
/*                                                                            */
/******************************************************************************/

#include "sattrack.h"

/******************************************************************************/
/*                                                                            */
/*  external functions                                                        */
/*                                                                            */
/******************************************************************************/

extern double absol(), scalar(), getElement(), reduce();

extern long   getDayNum();

extern int    checkKeyBoard(), controlISI(), decodeDate(), decodeTime(), 
              getSatListPtr(), initISI(), 
              readTle(), readTleFile(), satEclipse(), stopISI();

extern char   *dayName(), *getenv(), *monthName();

extern void   calcCityVectors(), calcCommonPerturb(), 
              calcSDP4(), calcSGP4(), calendar(), 
              changeElementUnits(), changeNoradUnits(), checkArguments(), 
              checkExit(), checkPerigeeHeight(), checkPropModelType(), 
              checkSwitchSat(), checkSwitchPage(), checkTimeZone(), 
              checkToggleTrack(), cleanSatName(), clipString(), convertTime(), 
              cross(), deepSpacePeriodics(), deepSpaceSecular(), 
              disableTrack(), dispTitle(), dispVersion(), doLiveCalcs(), 
              doLongPrediction(), doMultiSatTrackLoop(), doShortPrediction(), 
              doSingleSatTrackLoop(), doSleep(), getAziElev(), getDate(), 
              getDefaultData(), getDoppler(), getEnvironment(), 
              getGroundTrack(), getMode(), getNextPass(), 
              getNoradStateVector(), getNutation(), getNutationSeries(), 
              getOrbitNumber(), getPathLoss(), getPhase(), getPrecMatrix(), 
              getRange(), getRealTime(), getRefraction(), getSatModes(), 
              getSatParams(), getSatPrecession(), getSemiMajorAxis(), 
              getShuttleOrbit(), getSidTime(), getSiteParams(), 
              getSiteVector(), getSquintAngle(), getStateVector(), 
              getStateVectorX(), getSubSatPoint(), getSunVector(), 
              getTimeArgs(), getTimeParams(), getTimeZone(), getTleSets(), 
              getTopocentric(), getTrueAnomaly(), getUnixTime(), 
              initDeepSpace(), initMain(), initMultiSatLiveDisp(), 
              initMultiSatTrackLoop(), initRestart(), initSingleSatLiveDisp(), 
              initSingleSatTrackLoop(), initTerminal(), kepler(), keplerX(), 
              loadSatData(), loadSatElements(), lowerCase(), makeOutputFile(), 
              multMatVec(), printDate(), printMET(), printMode(), 
              printPredHeader(), printTime(), readCities(), readSatList(), 
              replaceBlanks(), saveSatData(), setupPrecmat(), shortString(), 
              showMainMenu(), sortSats(), trackAntenna(), trackingControl(), 
              trackRadio(), truncBlanks(), updateDrag(), updateGravity(), 
              updateGravityAndDrag(), updateLongPeriodics(), 
              updateShortPeriodics(), updateMultiLiveDisp(), 
              updateSingleLiveDisp(), upperCase();

/******************************************************************************/
/*                                                                            */
/*  external variables                                                        */
/*                                                                            */
/******************************************************************************/

extern double timeZoneHour[];

extern double precMatrix[3][3], precMatrixTr[3][3], siteRotMatGl[3][3], 
              sunPosGl[3], moonPosGl[3], satPosGl[3], satPosPrec[3], 
              satVelGl[3], satPosS[3], satVelS[3], sitePosGl[3], siteVelGl[3], 
              localVecSatGl[3], localVecSunGl[3], localVecMoonGl[3], 
              siteCtyVecGl[3], satAttGl[3], satSquintGl[3];

extern double epochDay, elsetEpochDay, elsetEpoch, deltaTimeX, 
              epochMeanAnomaly, epochRaan, epochMeanMotion, decayRate, 
              decayRateDot, bStarCoeff, epochArgPerigee, eccentricity, 
              inclination, sunRA, sunDec, sunAzimuth, sunElevation, sunDist, 
              moonRA, moonDec, moonAzimuth, moonElevation, moonDist, 
              refOrbit, curOrbit, orbitFract, stsOrbit, stsOrbitFract, 
              curMotion, curMotionX, meanAnomaly, trueAnomaly, trueAnomalyX, 
              semiMajorAxis, perigee, perigeeHeight, perigeePrec, satRadius, 
              raanPrec, curRaan, curRaanX, curArgPerigee, curArgPerigeeX, 
              curArgNodeX, satLat, satLong, satHeight, satAzimuth, 
              satElevation, satRange, trackAzimuth, trackElevation, 
              lastTrackAzi, lastTrackEle, trackAziRate, trackEleRate, 
              pathLoss, squintAngle, rangeRate, satVelocity, 
              beaconFreq, dopplerShift, perigeePhase, satPhase, maxPhase, 
              attLat, attLong, siteLat, siteLong, siteAlt, effEarthRadius, 
              prevDispEle, prevSatLat, defMinElevation, minElevation, 
              defDuration, duration, defStepTime, stepTime, startTime, 
              stopTime, realTime, utcTime, julianDate, lastJulianDateSun, 
              lastJulianDatePrec, lastJulianDateNute, totPsi, totEps, 
              equEquinox, launchTime, launchEpoch, timeZone, gasTime, lasTime, 
              gndTrkDist, atmPressure, ambTemperature, relHumidity, dummyd, 
              cosInclination, sinInclination, cosTrueAnomaly, sinTrueAnomaly, 
              cosSiteLat, sinSiteLat, cosSiteLong, sinSiteLong;

extern long   satNum, dayNumber, lastDayNum, launchDate, epochOrbitNum, 
              orbitNum, stsOrbitNum, curYearSec, lastTrackYearSec;

extern int    satOrder[MAXSATS];

extern int    ephemerisType, launchYear, launchMonth, launchDay, 
              launchHour, launchMin, launchSec, launchFlag, attitudeFlag, 
              elementSet, numModes, propModelType, batchModeFlag, debugFlag, 
              modelFlag, quickStartFlag, verboseFlag, timeZoneFlag, 
              timeZones, eclipseCode, eclipseRise, eclipseMax, eclipseSet, 
              stsFlag, geoSyncFlag, elevationFlag, newRiseFlag, passDispFlag, 
              countdownFlag, checkCountdown, shortPredFlag, satCrashFlag, 
              tleInvalidFlag, preLaunchFlag, preOrbitFlag, trackingFlag, 
              trackCtrlFlag, trackDispFlag, didMultDispFlag, objectNumFlag, 
              noPassFlag, xTermFlag, gndTrkFlag, justAcquFlag, justLostFlag, 
              trackObject, newTrackObjectFlag, firstLine, firstPage, 
              headerCol, numCities, oldCityNum, newCityNum, numSats, 
              numSatsAuto, numTle, numLines, numLinesX, numSatLines, 
              satLinePtr, transitFlag, sunTransitFlag, sunProximity, 
              sunTransit, mainChoice, dummyi;

extern char   modesDat[80], sitesDat[80], defaultsDat[80], defaultSatGroup[10], 
              defaultTimeZoneStr[10], timeZoneStr[10], elementFile[80], 
              satName[80], satTrackName[80], satAlias[80], fullSatAlias[80], 
              satFileName[80], siteName[80], fullSiteName[80], satGroup[10], 
              defaultSat[40], defaultSetTLE[40], defaultSetSTS[40], 
              defaultType[40], defaultSite[40], defaultNORAD[40], 
              elementType[40], modeString[10], timeString[80], epochString[40], 
              launchString[40], updateString[40], header[80], propModel[20], 
              gndTrkDir[10], gndTrkCity[80], dispStr[80], termTypeX[20], 
              antennaIO[20], radioIO[20], batchTimeZone[10], 
              batchSiteName[80], batchSatName[80], batchTleFile[80], 
              batchTleType[80], batchPredType[80], batchStartDate[80], 
              batchStartTime[80], batchStepTime[80], batchDuration[80], 
              batchMinElev[80], batchHardcopy[80];

extern char   sattrName[], sattrHeader[], sattrVersion[], predHeader[], 
              dispHeader[], callSign[], 
              *visibCode[], *dayNames[], *monthNames[], *timeZoneList[], 
              ch, *strpTerm, *strpHome;

extern FILE   *outFile;

/******************************************************************************/
/*                                                                            */
/*  structures                                                                */
/*                                                                            */
/******************************************************************************/

typedef struct {
    double lat, lng, alt, X, Y, Z;
    char   cty[40];
    } cityType;

extern cityType city[MAXCITIES];


typedef struct { 
    long tleSatNum;
    char tleLine0[20];
    char tleLine1[70];
    char tleLine2[70];
    } tleType;

extern tleType tle[MAXSATS];


typedef struct { 
    char satelName[20];
    } satelType;

extern satelType satel[MAXSATS];


typedef struct { 
    double minPhase, maxPhase;
    char   modeStr[5];
    } modeType;

extern modeType modes[MAXMODES];


typedef struct {
    double   epDay, elSetEp, launchEp, epInc, epRaan, epEcc, epArgPer;
    double   epMeanAnom, epMeanMot, epDecRate, epDecRateDot, epBstar, freq;
    double   attLtd, attLng, attX, attY, attZ, perigPh, maxPh;
    double   semiMajAxis, raanPr, periPr, refOrb, cosInc, sinInc;
    double   satOrb, stsOrb, satOrbFrac, stsOrbFrac;
    double   satAzi, satEle, satLastEle, satRng, satLtd, satLng, satHgt;
    double   nextRiseT, nextSetT, riseAzi, maxAzi, setAzi, maxEle, maxRng;
    double   ctyDist;
    long     satIdNum, epOrbNum, satOrbNum, stsOrbNum, numMd;
    int      elSet, ephType, eclCode, eclRise, eclMax, eclSet, modelType;
    int      statusFl, stsFl, geosyncFl, crashFl, invalidFl;
    int      launchFl, attitudeFl, prelaunchFl, preorbitFl, nopassFl;
    char     satellite[20], satelliteAlias[20], ctyDir[5], ctyStr[40];
    char     model[20];
    modeType satModes[MAXMODES];
    } satType;

extern satType sat[MAXSATS];

/******************************************************************************/
/*                                                                            */
/*  end of include file satglobalsx.h                                         */
/*                                                                            */
/******************************************************************************/
