/******************************************************************************/
/*                                                                            */
/*  Title       : sattrack.h                                                  */
/*  Author      : Manfred Bester, DL5KR                                       */
/*  Date        : 24Feb92                                                     */
/*  Last change : 05Oct94                                                     */
/*                                                                            */
/*  Synopsis    : Definitions of constants and parameters for 'sattrack',     */
/*                'amsat', 'checksum', 'selectsat' and 'tlexgen'.             */
/*                                                                            */
/*                                                                            */
/*  Copyright (c) 1992, 1993, 1994 Manfred Bester. All Rights Reserved.       */
/*                                                                            */
/*  Permission to use, copy, modify, and distribute this software and its     */
/*  documentation for educational, research and non-profit purposes, without  */
/*  fee, and without a written agreement is hereby granted, provided that the */
/*  above copyright notice and the following three paragraphs appear in all   */
/*  copies.                                                                   */
/*                                                                            */
/*  Permission to incorporate this software into commercial products may be   */
/*  obtained from the author, Dr. Manfred Bester, 1636 M. L. King Jr. Way,    */
/*  Berkeley, CA 94709, USA.                                                  */
/*                                                                            */
/*  IN NO EVENT SHALL THE AUTHOR BE LIABLE TO ANY PARTY FOR DIRECT, INDIRECT, */
/*  SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OF   */
/*  THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF THE AUTHOR HAS BEEN ADVISED  */
/*  OF THE POSSIBILITY OF SUCH DAMAGE.                                        */
/*                                                                            */
/*  THE AUTHOR SPECIFICALLY DISCLAIMS ANY WARRANTIES, INCLUDING, BUT NOT      */
/*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A   */
/*  PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON AN "AS IS"      */
/*  BASIS, AND THE AUTHOR HAS NO OBLIGATIONS TO PROVIDE MAINTENANCE, SUPPORT, */
/*  UPDATES, ENHANCEMENTS, OR MODIFICATIONS.                                  */
/*                                                                            */
/******************************************************************************/

#ifdef  TRUE
#undef  TRUE
#endif

#ifdef  FALSE
#undef  FALSE
#endif

#define TRUE                 -1
#define FALSE                 0
 
/******************************************************************************/
/*                                                                            */
/*  compiler flags                                                            */
/*                                                                            */
/******************************************************************************/

#define REVERSEVIDEO                             /* controls reverse video    */

/* #define SUNTRANSITS                           /* allows solar transits     */
/* #define ISI                                   /* needed for ISI telescopes */
/* #define XGRAPHICS                             /* not used presently        */

/******************************************************************************/
/*                                                                            */
/*  character strings                                                         */
/*                                                                            */
/******************************************************************************/

#define CALLSIGN              "DL5DK"            /* default station callsign  */

#define DATA                  "SatTrack/data"    /* resource directories      */
#define PREDICTION            "SatTrack/pred"
#define TLE                   "SatTrack/tle"

#define CITIES                "cities.dat"       /* resource file names       */
#define DEFAULTS              "defaults.dat"
#define MODES                 "modes.dat"
#define TLEX                  "tlex.dat"

#define XTERM                 "xterm"            /* X terminal type           */

/******************************************************************************/
/*                                                                            */
/*  header of NORAD two-line Keplerian element sets                           */
/*  (not used in 'sattrack' but in the auxiliary programs)                    */
/*                                                                            */
/******************************************************************************/

#define TLEHEADER             "- Current Two-Line Element Sets "

/******************************************************************************/
/*                                                                            */
/*  control flags and character strings for different propagation models      */
/*                                                                            */
/******************************************************************************/

#define TLEMEAN               0
#define LOWEARTH              1
#define DEEPSPACE             2

#define TLEMEANMODEL          "TLE Mean"
#define LOWEARTHMODEL         "SGP4"
#define DEEPSPACEMODEL        "SDP4"

/******************************************************************************/
/*                                                                            */
/*  command line arguments passed to the main program                         */
/*                                                                            */
/******************************************************************************/

#define BATCH                 "-B"
#define DEBUG                 "-D"
#define MODEL                 "-M"
#define QUICK                 "-Q"
#define TIMEZONE              "-T"
#define VERBOSE               "-V"

/******************************************************************************/
/*                                                                            */
/*  batch mode command line parameters                                        */
/*                                                                            */
/******************************************************************************/

#define NASA                  "NASA"
#define NORAD                 "NORAD"
#define SHORTPR               "SHORTPR"
#define LONGPR                "LONGPR"
#define TRANSIT               "TRANSIT"
#define NOW                   "NOW"
#define AUTO                  "AUTO"
#define HARDCOPY              "HARDCOPY"

/******************************************************************************/
/*                                                                            */
/*  menu selection parameters                                                 */
/*                                                                            */
/******************************************************************************/

#define DX                    "D"
#define FX                    "F"
#define LX                    "L"
#define MX                    "M"
#define PX                    "P"
#define QX                    "Q"
#define RX                    "R"
#define SX                    "S"
#define TX                    "T"
#define VX                    "V"
#define YES                   "Y"
#define NO                    "N"

#define START                 0
#define DISPLAY               1
#define SINGLESAT             2
#define MULTISAT              3
#define PREDICT               4
#define TEST                  5
#define RESTART               6

#define QUIT                  997
#define EXIT                  998
#define VOID                  999

/******************************************************************************/
/*                                                                            */
/*  control flags for multisat live display                                   */
/*                                                                            */
/******************************************************************************/

#define OFF                   0
#define ON                    1
#define LIST                  2
#define ORDER                 3
#define ELEV                  4
#define NAME                  5
#define OBJNUM                6
#define MANTRK                7
#define AUTOTRK               8
#define SELECT                9
#define MARK                  10

/******************************************************************************/
/*                                                                            */
/*  antenna controller and radio types                                        */
/*                                                                            */
/*  these are used to select the proper control sequences in 'satctrl.c' and  */
/*  for the ISI telescopes in 'sattele.c'                                     */
/*                                                                            */
/******************************************************************************/

#define NONE                 -1
#define GENERIC               0

#define ISITELESCOPE          1
#define KANSASCITY            2

#define FT736                 1
#define IC970                 2

#ifdef ISI
#define RADIOTYPE             NONE
#define ANTENNATYPE           ISITELESCOPE
#else
#define RADIOTYPE             GENERIC
#define ANTENNATYPE           GENERIC
#endif

#define ANTENNADEV            "/dev/null"        /* ground station interfaces */
#define RADIODEV              "/dev/null"

/******************************************************************************/
/*                                                                            */
/*  printer options                                                           */
/*                                                                            */
/******************************************************************************/

#define PRINTCMD              "enscript"
#define PRINTOPT              "-h -f"
#define FOND                  "Courier"
#define SIZE9                 "9"
#define SIZE10                "10"
#define SIZE12                "12"

/******************************************************************************/
/*                                                                            */
/*  math functions                                                            */
/*                                                                            */
/******************************************************************************/

#define SQR(x)                ((x)*(x))

/******************************************************************************/
/*                                                                            */
/*  general numerical constants                                               */
/*                                                                            */
/******************************************************************************/

#define ZERO                  0.0
#define ONEPPB                1.0e-9
#define ONEPPM                1.0e-6
#define TWOPPM                2.0e-6
#define ONETHIRD              (1.0/3.0)
#define TWOTHIRDS             (2.0/3.0)
#define THREEHALFS            (3.0/2.0)
#define ONE                   1.0
#define ONEMEG                1.0e6
#define TWOMEG                2.0e6

/******************************************************************************/
/*                                                                            */
/*  numerical constants for unit conversions                                  */
/*                                                                            */
/******************************************************************************/

#ifdef  PI
#undef  PI
#endif

#ifdef  TWOPI
#undef  TWOPI
#endif

#define PI                    3.14159265358979323846264338
#define TWOPI                 (2.0*PI)
#define FOURPI                (4.0*PI)
#define HALFPI                (0.5*PI)
#define THREEHALFPI           (1.5*PI)

#define CRH                   (24.0/TWOPI)         /* convert rad into hours  */
#define CRS                   (86400.0/TWOPI)      /* convert rad into sec    */
#define CRD                   (360.0/TWOPI)        /* convert rad into deg    */
#define CRAM                  (21600.0/TWOPI)      /* convert rad into arcmin */
#define CRAS                  (1296000.0/TWOPI)    /* convert rad into arcsec */
#define CDR                   (TWOPI/360.0)        /* convert deg into rad    */
#define CAMR                  (TWOPI/21600.0)      /* convert arcmin into rad */
#define CASR                  (TWOPI/1296000.0)    /* convert arcsec into rad */
#define CRREV                 (1.0/TWOPI)          /* convert rad into rev    */

#define HALFDEG               (0.5*CDR)            /* half a deg [rad]        */

#define MPD                   1440.0               /* minutes per day         */
#define MPD2                  (MPD*MPD)            /* (minutes per day)^2     */
#define MPD3                  (MPD2*MPD)           /* (minutes per day)^3     */
#define SPD                   86400.0              /* seconds per day         */

#define CKMM                  1000.0               /* convert km to m         */
#define CMKM                  1.0e-3               /* convert m to km         */
#define CKMNM                 0.539956804          /* convert km to naut. mil.*/
#define CHZKHZ                1.0e-3               /* convert Hz to kHz       */
#define CKHZMHZ               1.0e-3               /* convert kHz to MHz      */
#define CHZMHZ                1.0e-6               /* convert Hz to MHz       */

/******************************************************************************/
/*                                                                            */
/*  numerical constants describing the Earth's orbit and figure               */
/*                                                                            */
/******************************************************************************/

#define EARTHSMA              149597892.0          /* 1 AU [km]               */
#define EARTHRADIUS           6378.135             /* equatorial radius [km]  */
#define EARTHECCEN            0.01675104           /* Earth's orbit eccentr.  */
#define F                     0.003352813178       /* geoid model parameters  */
#define FF                    (F*F)
#define FFF                   (FF*F)
#define F1                    (-F - 0.5*FF)
#define F2                    (0.5*FF + 0.5*FFF)
#define F3                    (-1.0/3.0*FFF)
#define REFF0                 (1.0 - 0.5*F + 5.0/16.0*FF + 5.0/32.0*FFF)
#define REFF1                 (0.5*F - 13.0/64.0*FFF)
#define REFF2                 (-5.0/16.0*FF - 5.0/32.0*FFF)
#define REFF3                 (13.0/64.0*FFF)

/******************************************************************************/
/*                                                                            */
/*  numerical constants describing the apparent size of the Sun and the       */
/*  proximity limit for calculating transits across the solar disk            */
/*                                                                            */
/******************************************************************************/

#define SUNRADIUS             695980.0             /* equatorial radius [km]  */
#define SUNDISKRAD            (16.0*CAMR)          /* Sun disk radius [rad]   */
#define SUNPROX               48.0                 /* Sun prox limit [arcmin] */

/******************************************************************************/
/*                                                                            */
/*  numerical constants describing the motions within the solar system        */
/*                                                                            */
/******************************************************************************/

#define JULCENT               36525.0              /* mean solar days / jcy   */
#define TROPCENT              36524.219879         /* mean solar days / cy    */
#define TROPYEAR              (TROPCENT/100.0)     /* mean solar days / year  */
#define JULDAT1900            2415020.0            /* Julian date of 1900.0   */
#define JULDAT1950            2433282.423          /* Julian date of 1950.0   */
#define JULDAT2000            2451545.0            /* Julian date of 2000.0   */
#define SIDSOLAR              1.002737909350       /* sidereal rotation rate  */
#define SIDRATE               (TWOPI/SPD*SIDSOLAR) /* [rad/s]                 */

/******************************************************************************/
/*                                                                            */
/*  physical constants                                                        */
/*                                                                            */
/******************************************************************************/

#define CVAC                  2.99792458e5         /* speed of light [km/s]   */

#define GM                    398603.2             /* [km^3/s^2]              */
#define GMSGP                 398600.7995          /* value used in SGP model */

#define KEPLER                42241.19311          /* GM^(1/3)*(SPD/2PI)^(2/3)*/
#define KEPLERSGP             42241.10831          /* value used in SGP model */
                                                   /* with a [km] and T [min] */

/******************************************************************************/
/*                                                                            */
/*  atmospheric parameters used for calculation of refraction                 */
/*                                                                            */
/******************************************************************************/

#define SCALEHEIGHT           8.0              /* atmosph. scale height [km]  */
#define ATMPRESS              760.0            /* standard atm. press. [mmHg] */
#define AMBTEMP               15.0             /* standard amb. temp.  [C]    */
#define RELHUMID              30.0             /* standard rel. humidity [%]  */
#define WAVEL                 0.550            /* wavelength of observ. [um]  */
#define REFWAVEL              0.550            /* reference wavelength [um]   */

/******************************************************************************/
/*                                                                            */
/*  satellite parameters                                                      */
/*                                                                            */
/******************************************************************************/

#define BEACONFREQ            146.0            /* default beacon frequ. [MHz] */
#define MAXPHASE              256.0            /* max. value for phase number */

#define MAXMODES              8                /* max. number satellite modes */
#define MAXCITIES             800              /* max. number of cities       */
#define MAXSATS               600              /* max. number of satellites   */

#define MAXCITYLEN            37               /* max. length of city name    */
#define MAXSATNAMELEN         14               /* max. length of sat name     */

#define TLELIMIT              0.25             /* validity limit for TLE set  */
                                               /* [rev]                       */

/******************************************************************************/
/*                                                                            */
/*  satellite eclipse parameters                                              */
/*                                                                            */
/******************************************************************************/

#define SAT                   0                /* code for calculation of     */
#define SUN                   1                /* azimuth and elevation       */
#define MOON                  2

#define DAY                   0                /* code for display of eclipse */
#define PARTIAL               1                /* conditions                  */
#define NIGHT                 2
#define VISIBLE               3
#define BLANK                 4

#define TWILIGHT              (-6.0*CDR)       /* civil twilight limit        */
#define VLOWELEV              (-15.0*CDR)      /* low elevation level 1 [rad] */
#define LOWELEV               (-2.0*CDR)       /* low elevation level 2 [rad] */
#define MAXELEV               (40.0*CDR)       /* max elevation warn limit    */

#define TRACKLIMIT            (-3.0*CDR)       /* antenna/radio track limit   */

#define MAXAZIRATE            (5.0*CDR)        /* maximum azimuth rate [rad]  */
#define MAXELERATE            (5.0*CDR)        /* maximum elevation rate [rad]*/

/******************************************************************************/
/*                                                                            */
/*  control flags and parameters for geosynchronous satellites                */
/*                                                                            */
/******************************************************************************/

#define GEOSYNC               1
#define GEOSTAT               2

#define GEOSYNCMOT            0.05             /* maximum deviation in mean   */
                                               /* motion from 1 rev/d for     */
                                               /* geosynchronous satellites   */

#define GEOSTATINC            (10.0*CDR)       /* maximum inclination [deg]   */
                                               /* for geostationary sats      */

#define MAXDAYS               2.0              /* limit for rise time search  */
                                               /* for non-geosynchonous sats  */

#define MAXDAYSSYNC           3.0              /* limit for rise time search  */
                                               /* for geosynchonous sats [d]  */

/******************************************************************************/
/*                                                                            */
/*  event time parameters                                                     */
/*                                                                            */
/******************************************************************************/

#define HALFMIN               (0.5/MPD)        /* half a minute [d]           */
#define ONEMIN                (1.0/MPD)        /* one minute [d]              */
#define THREEMIN              (3.0/MPD)        /* three minutes [d]           */
#define NINEMIN               (9.0/MPD)        /* nine minutes [d]            */
#define TENMIN                (10.0/MPD)       /* ten minutes [d]             */

#define SUNUPDATEINT          (15.0/MPD)       /* update interval Sun [d]     */
#define PRECUPDATEINT         (120.0/MPD)      /* update interval precession  */
#define NUTEUPDATEINT         (120.0/MPD)      /* update interval nutation    */

#define FASTUPDATEINT         5                /* display update interval [s] */
#define MEDUPDATEINT          10               /* display update interval [s] */
#define SLOWUPDATEINT         15               /* display update interval [s] */

#define SLEEPTIME             100000           /* sleep time [us]             */

#ifdef ISI
#define TRACKTIMEAHEAD        10               /* tracking time offset [s]    */
#define TRACKINT              1                /* tracking time interval [s]  */
#else
#define TRACKTIMEAHEAD        0                /* tracking time offset [s]    */
#define TRACKINT              1                /* tracking time interval [s]  */
#endif


/******************************************************************************/
/*                                                                            */
/*  live display parameters                                                   */
/*                                                                            */
/******************************************************************************/

#define DISPCOLUMNS           80               /* number of columns on disp   */
#define DISPLINES             24               /* number of lines on display  */
#define XDISPCOLUMNS          132              /* number of columns on Xdisp  */
#define XDISPLINES            64               /* number of lines on Xdisplay */

/******************************************************************************/
/*                                                                            */
/*  I/O control parameters                                                    */
/*                                                                            */
/******************************************************************************/

#define STDIN_FILENO          0                /* used in checkKeyboard()     */

/******************************************************************************/
/*                                                                            */
/*  X color indices                                                           */
/*                                                                            */
/******************************************************************************/

#define WHITE           0                      /* not used presently          */
#define RED             1
#define GREEN           2
#define BLUE            3
#define BLACK           4

#define NUMCOLORS       5

/******************************************************************************/
/*                                                                            */
/*  end of include file sattrack.h                                            */
/*                                                                            */
/******************************************************************************/
