/******************************************************************************/
/*                                                                            */
/*  Title       : satchar.c                                                   */
/*  Author      : Manfred Bester, DL5KR                                       */
/*  Date        : 09Jul93                                                     */
/*  Last change : 05Oct94                                                     */
/*                                                                            */
/*  Synopsis    : Routines for character string manipulation.                 */
/*                                                                            */
/*                                                                            */
/*  Copyright (c) 1992, 1993, 1994 Manfred Bester. All Rights Reserved.       */
/*                                                                            */
/*  Permission to use, copy, modify, and distribute this software and its     */
/*  documentation for educational, research and non-profit purposes, without  */
/*  fee, and without a written agreement is hereby granted, provided that the */
/*  above copyright notice and the following three paragraphs appear in all   */
/*  copies.                                                                   */
/*                                                                            */
/*  Permission to incorporate this software into commercial products may be   */
/*  obtained from the author, Dr. Manfred Bester, 1636 M. L. King Jr. Way,    */
/*  Berkeley, CA 94709, USA.                                                  */
/*                                                                            */
/*  IN NO EVENT SHALL THE AUTHOR BE LIABLE TO ANY PARTY FOR DIRECT, INDIRECT, */
/*  SPECIAL, INCIDENTAL, OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OF   */
/*  THIS SOFTWARE AND ITS DOCUMENTATION, EVEN IF THE AUTHOR HAS BEEN ADVISED  */
/*  OF THE POSSIBILITY OF SUCH DAMAGE.                                        */
/*                                                                            */
/*  THE AUTHOR SPECIFICALLY DISCLAIMS ANY WARRANTIES, INCLUDING, BUT NOT      */
/*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A   */
/*  PARTICULAR PURPOSE. THE SOFTWARE PROVIDED HEREUNDER IS ON AN "AS IS"      */
/*  BASIS, AND THE AUTHOR HAS NO OBLIGATIONS TO PROVIDE MAINTENANCE, SUPPORT, */
/*  UPDATES, ENHANCEMENTS, OR MODIFICATIONS.                                  */
/*                                                                            */
/******************************************************************************/

#include <stdio.h>
#include <string.h>

#include "satglobalsx.h"
#include "sattrack.h"

#ifndef SUNOS4
#include <stdlib.h>
#endif

/******************************************************************************/
/*                                                                            */
/* upperCase: changes lower to upper case letters                             */
/*                                                                            */
/******************************************************************************/

void upperCase(string)

char *string;

{
    int i;

    for (i = 0; i < strlen(string); i++)
    {
        if (string[i] >= 'a' && string[i] <= 'z')
            string[i] -= 'a' - 'A';
    }

    return;
}

/******************************************************************************/
/*                                                                            */
/* lowerCase: changes upper to lower case letters                             */
/*                                                                            */
/******************************************************************************/

void lowerCase(string)

char *string;

{
    int i;

    for (i = 0; i < strlen(string); i++)
    {
        if (string[i] >= 'A' && string[i] <= 'Z')
            string[i] -= 'A' - 'a';
    }

    return;
}

/******************************************************************************/
/*                                                                            */
/* truncBlanks: truncates trailing blanks from character string               */
/*                                                                            */
/******************************************************************************/

void truncBlanks(string)

char *string;

{
    int i;

    i = strlen(string) - 1;

    while (string[i] == ' ')
    {
        i--;
    }

    string[i+1] = '\0';                          /* add termination character */
    return;
}

/******************************************************************************/
/*                                                                            */
/* shortString: shortens character string up to next blank from the end       */
/*                                                                            */
/******************************************************************************/

void shortString(strng,fullStrng)

char *strng, *fullStrng;

{
    int i;

    strncpy(strng,fullStrng,15);

    if (strlen(strng) == 15)
    {
        if (fullStrng[14] == ' ')
            strng[14] = '\0';

        else
        {
            if (fullStrng[15] != ',' && fullStrng[15] != ' ')
            {
                i = strlen(strng) - 1;

                do
                {
                    i--;
                }
                while (strng[i] != ' ');

                strng[i] = '\0';
            }
        }

        for (i = 0; i < 15; i++)
        {
            if (strng[i] == ',')
                strng[i] = '\0';
        }
    }

    return;
}

/******************************************************************************/
/*                                                                            */
/* clipString: clips N characters plus leading blanks off the beginning of a  */
/*             character string                                               */
/*                                                                            */
/******************************************************************************/

void clipString(charStr,N)

int  N;
char *charStr;

{
    int  i, j, firstChar;
    char tmpStr[100];

    firstChar = FALSE;
    j = 0;

    for (i = 0; i < strlen(charStr) - N; i++) 
    {

       if (charStr[i+N] != ' ' || (charStr[i+N] == ' ' && firstChar))
       {
           tmpStr[j] = charStr[i+N];
           j++;
           firstChar = TRUE;
       }
    }

    tmpStr[j] = '\0';                            /* add termination character */
    sprintf(charStr,"%s",tmpStr);
    return;
}

/******************************************************************************/
/*                                                                            */
/* cleanSatName: cleans up satellite name                                     */
/*                                                                            */
/******************************************************************************/

void cleanSatName(charStr)

char *charStr;

{
    int  i;

    if (strlen(charStr) > MAXSATNAMELEN)
        charStr[MAXSATNAMELEN] = '\0';

    if (charStr[MAXSATNAMELEN-1] == '/' ||
        charStr[MAXSATNAMELEN-1] == ' ')
        charStr[MAXSATNAMELEN-1] = '\0';

    for (i = 0; i < strlen(charStr); i++)
    {
        if (charStr[i] == '(')
            charStr[i] = '\0';
    }

    return;
}

/******************************************************************************/
/*                                                                            */
/* replaceBlanks: replaces underscore characters by a blank character         */
/*                                                                            */
/******************************************************************************/

void replaceBlanks(charStr)

char *charStr;

{
    int  i;

    for (i = 0; i < strlen(charStr); i++)
    {
        if (charStr[i] == '_')
            charStr[i] = ' ';
    }

    return;
}

/******************************************************************************/
/*                                                                            */
/* End of function block satchar.c                                            */
/*                                                                            */
/******************************************************************************/
